/* Sample Sonos JS App. 
 * sonos.js must be included before this file
 *
 * It makes some big assumptions how things will be done.
 * Of course you don't have to use this to write your app.
 *
 */

var app = {};

function updateText(name, text) {
    var element = document.getElementById(name);
    if (!element.innerHTML || element.innerHTML != text) {
        element.innerHTML = text;
    }
}

function updateToggle(first, second, doFirst) {
    document.getElementById(first).style.display = (doFirst?"inline":"none");
    document.getElementById(second).style.display  = (doFirst?"none":"inline");
}

function start() {
    app.currentMusicPath = "";
    app.rootLastUpdate = 0;
    if (!app.removegif)
        alert("Must set app.removegif");
    if (!app.playgif)
        alert("Must set app.playgif");
    if (!app.addgif)
        alert("Must set app.addgif");
    sonos.start();
}

function setCurrentZone(zoneId) {
    if (app.currentZoneId && app.currentZoneId == zoneId) {
        return;
    }
    app.currentZoneId = zoneId;
    drawControl(zoneId);
    drawQueue(zoneId);
}
function needZone() {
    if (!app.currentZoneId) {
        alert("Please select a Zone first.");
        return 1;
    }
    return 0
}

function doAction(action) {
    if (needZone()) return;
    sonos.sendControlAction(app.currentZoneId, action);
}

function doQAction(action, id) {
    if (needZone()) return;
    sonos.sendQueueAction(app.currentZoneId, action, id);
}

function doMAction(action, path) {
    if (needZone()) return;
    sonos.sendMusicAction(app.currentZoneId, action, path);
}

function doPlaylistDelete(path) {
    if (needZone()) return;
    if (confirm("Delete " + unescape(path) + "?")) {
        sonos.sendMusicAction(app.currentZoneId, "DeleteMusic", path);
    }
}

function doSaveQ() {
    if (needZone()) return;
    var element = document.getElementById("savequeuename");
    if (element.value == "") {
        alert("Please enter a name");
        return;
    }
    sonos.sendSaveAction(app.currentZoneId, escape(element.value));
    element.value = "";
}

function doSearch(auto) {
    if (auto && !app.currentZoneId) {
        return; // Don't bug the user if this is a auto search
    }

    if (needZone()) return;

    var element = document.getElementById("msearch");
    app.currentMusicPath = "Search: "+ escape(element.value);

    if (element.value == "") {
        browseTo("");
        return;
    }

    if (auto && element.value.length < 2) {
        return; // Don't auto search if 1 char, since could be slow
    }

    if (sonos.music[app.currentMusicPath]) {
        drawMusic(app.currentMusicPath);
    } else {
        sonos.sendMusicSearch(app.currentZoneId, escape(element.value));
    }
}

function browseTo(path) {
    if (needZone()) return;

    app.currentMusicPath = path;

    if (sonos.music[app.currentMusicPath]) {
        drawMusic(app.currentMusicPath);
    } else {
        sonos.sendMusicAction(app.currentZoneId, "Browse", app.currentMusicPath);
    }
}

function browseBack() {
    if (needZone()) return;

    var slash = app.currentMusicPath.lastIndexOf("/");
    if (slash != -1) {
        browseTo(app.currentMusicPath.substr(0, slash));
    }
}

function drawZones() {
    var str = "";
    for (i=0; i < sonos.zones.length; i++) {
        var zone = sonos.zones[i];
        str += "<A HREF=\"#\" onClick=\"setCurrentZone('" + sonos[zone].zoneId + "')\" > " + sonos[zone].zoneName + "</A> <BR>\n";
    }
    updateText("zones", str);
}

function drawControl(zoneId) {
    if (app.currentZoneId != zoneId) {
        return;
    }

    var zone = sonos[zoneId];

    updateText('currentzonename', zone.zoneName);
    updateText('song', zone.song);
    updateText('album', zone.album);
    updateText('artist', zone.artist);
    updateText('tracknum', zone.tracknum);
    updateText('tracktot', zone.tracktot);
    updateToggle("pause", "play", zone.mode == 1);
    updateToggle("shuffleoff", "shuffleon", zone.shuffle);
    updateToggle("repeatoff", "repeaton", zone.repeat);
    updateToggle("muteoff", "muteon", zone.muted);
    updateText('volume', zone.volume);
}

function drawQueue(zoneId) {
    if (app.currentZoneId != zoneId) {
        return;
    }

    var str = new Array();
    for (i=0; i < sonos[app.currentZoneId].queue.length; i++) {
        var item = sonos[app.currentZoneId].queue[i];
        str.push("<A HREF=\"#\" onClick=\"doQAction('Remove', '" + item.id + "')\" ><IMG SRC="+app.removegif + "></A>");
        str.push("<A HREF=\"#\" onClick=\"doQAction('Seek', '" + item.id + "')\" > " + item.name + "</A> <BR>");
    }
    updateText("queuedata", str.join(""));
}

function drawMusic(path) {
    if (path != app.currentMusicPath) {

        // Got a refresh for top, might mean we should refresh the screen
        if ((path == "") && !sonos.music[app.currentMusicPath]) {
            browseTo(app.currentMusicPath);
        }
        return;
    }

    var isSearch = (path.substr(0,8) == "Search: ");
    var isPlaylist = (unescape(path).substr(0,10) == "/#Playlist");
    var isRadio = (unescape(path).substr(0,7) == "/#Radio");

    if (path == "") {
        updateText("musicpath", "/");
        document.getElementById("rootmusicdata").style.display = "inline";
        document.getElementById("musicdata").style.display     = "none";
        if (app.rootLastUpdate == sonos.musicLastUpdate[path])
            return;
        app.rootLastUpdate = sonos.musicLastUpdate[path];
    } else {
        updateText("musicpath", unescape(path));
        document.getElementById("rootmusicdata").style.display = "none";
        document.getElementById("musicdata").style.display     = "inline";
    }

    var str = new Array();

    for (i=0; i < sonos.music[path].length; i++) {
        var item = sonos.music[path][i];
        if (!isRadio) {
            str.push("<A HREF=\"#\" onClick=\"doMAction('AddMusic', '" + item.path + "')\" ><IMG SRC="+app.addgif+"></A>");
        }
        str.push("<A HREF=\"#\" onClick=\"doMAction('PlayMusic', '" + item.path + "')\" ><IMG SRC="+app.playgif+"></A>");
        if (isPlaylist) {
            str.push("<A HREF=\"#\" onClick=\"doPlaylistDelete('" + item.path + "')\" ><IMG SRC="+app.removegif+"></A>");
        }
        if (item.isSong) {
            if (isSearch) {
                str.push(unescape(item.path) + "<BR>\n");
            } else {
                str.push(item.name + "<BR>\n");
            }
        } else {
            str.push("<A HREF=\"#\" onClick=\"browseTo('" + item.path + "')\" > ");
            
            if (isSearch) {
                str.push (unescape(item.path) + "</A> <BR>\n");
            } else {
                str.push (item.name + "</A> <BR>\n");
            }
        }
    }
    var text = str.join("");
    if (path == "") {
        updateText("rootmusicdata", text);
    } else {
        updateText("musicdata", text);
    }
}
