// Public Functions
/* To use this script, 4 functions must be implemented
 *
 * drawZones()
 *    The available zones have changed.
 *    sonos.zones is an array of the zone ids
 *    sonos[zoneId] is an object with lots of info about the zone
 * 
 * drawControl(zoneId)
 *    The control data for a zone has changed
 *    sonos[zoneId] is an object with lots of info about the zone
 *
 * drawQueue(zoneId)
 *    The queue for a zone has changed
 *    sonos[zoneId].queue is an array of objects with info about the
 *    items in the queue
 *
 * drawMusic(path)
 *    A Music query has returned, path is "*Search*" for searches.
 *    sonos.music[path] is an array of objects with info about the 
 *    music at the path location
 *
 */
 
var sonos = {};

sonos.start = function() {
    sonos.music = {};
    sonos.musicLastUpdate = {};
    sonos._lastUpdate = 1;
    sonos._fetch();
}

sonos.sendAction = function(action, other) {
    if (!other)
        other = "";
    sonos._loadData("/action.html?NoWait=1&action=" + action + other);
}

sonos.sendControlAction = function(zoneId, action) {
    sonos.sendAction(action, "&zone=" + zoneId);
}

sonos.sendSaveAction = function(zoneId, name) {
    sonos.sendAction("Save", "&zone=" + zoneId + "&savename=" + name);
}

sonos.sendQueueAction = function(zoneId, action, id) {
    sonos.sendAction(action, "&zone=" + zoneId + "&queue=" + id);
}

sonos.sendMusicAction = function(zoneId, action, path) {
    sonos.sendAction(action, "&zone=" + zoneId + "&mpath=" + path);
}

sonos.sendMusicSearch = function(zoneId, str) {
    sonos._loadData("/action.html?zone=" + zoneId + "&lastupdate="+sonos._lastUpdate + "&msearch="+str);
}


// Private Functions
sonos._loadData = function(filename, afterFunc) {
    Http.get(filename, function (data) {
        eval(data);
        if (afterFunc)
            eval(afterFunc);
    });
}

sonos._doFetch = function() {
    sonos._loadData("/data.html?action=Wait&lastupdate="+sonos._lastUpdate, "sonos._fetch();");
}

sonos._fetch = function() {
    window.setTimeout("sonos._doFetch();", 100);
}

sonos._setLastUpdate = function(lastUpdate) {
    sonos._lastUpdate = lastUpdate;
}

sonos._setZones = function() {
    if (sonos.zoneUpdate && sonos.zoneUpdate == arguments[0]) {
        return;
    }
    sonos.zoneUpdate = arguments[0];
    sonos.zones = new Array((arguments.length-1)/2);
    for (i=1, j=0; i < arguments.length; i+=2, j++) {
        sonos.zones[j] = arguments[i];
        sonos[arguments[i]] = {};
        sonos[arguments[i]].zoneId    = arguments[i];
        sonos[arguments[i]].zoneName  = arguments[i+1];
    }
    drawZones();
}

sonos._startQueue = function(zoneId, lastUpdate) {
    sonos[zoneId].queue = new Array();
    sonos[zoneId]._queueLastUpdate = lastUpdate;
}

sonos._addQueue = function(zoneId, name, id) {
    var i = sonos[zoneId].queue.length;
    var obj = {};
    obj.name = name;
    obj.id = id;
    sonos[zoneId].queue[i] = obj;
}

sonos._finishQueue = function(zoneId) {
    drawQueue(zoneId, sonos[zoneId]._queueLastUpdate);
}

sonos._startMusic = function(path, lastUpdate) {
    // Refresh of top, drop the cache
    if (path == "") {
        sonos.music = {};
        sonos.musicLastUpdate = {};
    }

    sonos.music[path] = new Array();
    sonos.musicLastUpdate[path] = lastUpdate;
}

sonos._addMusic = function(root, name, path, isSong) {
    var i = sonos.music[root].length;
    var obj = {};
    obj.name = name;
    obj.path = path;
    obj.isSong = isSong;
    sonos.music[root][i] = obj;
}

sonos._finishMusic = function(path) {
    drawMusic(path);
}

sonos._setZoneInfo = function(zoneId, lastUpdate, volume, muted, mode, shuffle, repeat, isradio, tracknum, tracktot, song, album, artist) {
    if (sonos[zoneId] && sonos[zoneId]._lastUpdate == lastUpdate) {
        return;
    }

    sonos[zoneId]._lastUpdate  = lastUpdate;
    sonos[zoneId].volume      = volume;
    sonos[zoneId].muted       = muted;
    sonos[zoneId].mode        = mode;
    sonos[zoneId].shuffle     = shuffle;
    sonos[zoneId].repeat      = repeat;
    sonos[zoneId].isradio     = isradio;
    sonos[zoneId].tracknum    = tracknum;
    sonos[zoneId].tracktot    = tracktot;
    sonos[zoneId].song        = song;
    sonos[zoneId].album       = album;
    sonos[zoneId].artist      = artist;

    drawControl(zoneId);
}

